/**********************************************************************
audio play & record (Linux, Solaris, IRIX)

$Id: audio.h,v 1.4 1997/11/11 17:59:03 purnhage Exp $

Header file: playrec.h

Authors:
HP    Heiko Purnhagen, Uni Hannover <purnhage@tnt.uni-hannover.de>
NM    Nikolaus Meine, Uni Hannover (c/o Heiko Purnhagen)
BE    Bernd Edler, Uni Hannover <edler@tnt.uni-hannover.de>

Changes:
16-sep-98   HP/NM   born, based on auplay.c and aurec.c
            HP/BE   ... and play_list.c
**********************************************************************/

/* Audio play & record for Solaris, Linux, IRIX. */
/* Sample format: 16 bit twos complement, uniform quantisation */

/* Multi channel data is interleaved: l0 r0 l1 r1 ... */


#ifndef _playrec_h_
#define _playrec_h_


/* ---------- declarations ---------- */

typedef struct PRStreamStruct PRStream;	/* play/rec stream handle */


/* ---------- functions ---------- */

#ifdef __cplusplus
extern "C" {
#endif


/* PRInit() */
/* Init audio play & record. */

void PRInit (
  int debugLevel);		/* in: debug level */
				/*     0=off  1=basic  2=full */


/* PROpenRead() */
/* Open play/rec stream for reading. */

PRStream *PROpenRead (
  int device,			/* in: device (0=default) */
  int *numChannel,		/* in/out: number of channels */
  float *fSample);		/* in/out: sampling frequency [Hz] */
				/*  numChannel & fSample are set */
				/*  according to audio device capabilities */
				/* returns: */
				/*  play/rec stream (handle) */
				/*  or NULL if error */


/* PROpenWrite() */
/* Open play/rec stream for writing. */

PRStream *PROpenWrite (
  int device,			/* in: device (0=default) */
  int *numChannel,		/* in/out: number of channels */
  float *fSample);		/* in/out: sampling frequency [Hz] */
				/*  numChannel & fSample are set */
				/*  according to audio device capabilities */
				/* returns: */
				/*  play/rec stream (handle) */
				/*  or NULL if error */


/* PRReadData() */
/* Read data from play/rec stream. */

long PRReadData (
  PRStream *stream,		/* in: play/rec stream (handle) */
  short *data,			/* out: data[] */
  long numSample);		/* in: number of samples to be read */
				/* returns: */
				/*  number of samples read */


/* PRWriteData() */
/* Write data to play/rec stream. */

void PRWriteData (
  PRStream *stream,		/* in: play/rec stream (handle) */
  short *data,			/* in: data[] */
  long numSample);		/* in: number of samples to be written */


/* PRClose() */
/* Close play/rec stream.*/

void PRClose (
  PRStream *stream);		/* in: play/rec stream (handle) */


#ifdef __cplusplus
}
#endif

#endif	/* #ifndef _playrec_h_ */

/* end of playrec.h */

